@@ -1,6 +1,6 @@
 '''Simple messaging with RabbitMQ and Python.'''
 
-__version__ = '0.0.7'
+__version__ = '0.0.8'
 
 import logging
 import pickle
@@ -13,6 +13,7 @@ log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
 
 Errors = (
+    pika.exceptions.StreamLostError,
     pika.exceptions.ConnectionClosed,
     pika.exceptions.ChannelClosed,
     pika.exceptions.ChannelWrongStateError,
@@ -96,7 +97,7 @@ class Queue:
         try:
             return self._put(msg, priority=priority)
         except Errors as e:
-            log.debug(e)
+            log.error(f'{e}, retrying ...')
         
         self.setup()
         self._put(msg, priority=priority)
@@ -105,7 +106,7 @@ class Queue:
         try:
             self.channel.basic_reject(delivery_tag=self._method.delivery_tag, requeue=True)
         except Errors as e:
-            log.debug(e)
+            log.error(f'{e}, retrying ...')
             self.setup()
 
         self._processing = False
@@ -115,7 +116,7 @@ class Queue:
         try:
             self.channel.basic_ack(delivery_tag=self._method.delivery_tag)
         except Errors as e:
-            log.debug(e)
+            log.error(f'{e}, retrying ...')
             self.setup()
 
         self._processing = False
@@ -184,7 +185,7 @@ class Queue:
         try:
             self.channel.queue_purge(queue=self.queue)
         except Errors as e:
-            log.debug(e)
+            log.error(f'{e}, retrying ...')
             self.setup()
             self.channel.queue_purge(queue=self.queue)
 
@@ -192,7 +193,7 @@ class Queue:
         try:
             self.channel.queue_delete(queue=self.queue)
         except Errors as e:
-            log.debug(e)
+            log.error(f'{e}, retrying ...')
             self.setup()
             self.channel.queue_delete(queue=self.queue)
 
